#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 simple-sendfile
version:              0.2.32
visibility:           public
id:                   simple-sendfile-0.2.32-A2kk7hI8jkyIuonFf6AuD9
key:                  simple-sendfile-0.2.32-A2kk7hI8jkyIuonFf6AuD9
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.

category:             Network
abi:                  00a0da6d7f4cf94710a4dc15e73cb833
exposed:              True
exposed-modules:      Network.Sendfile System.Linux.Sendfile
hidden-modules:       Network.Sendfile.Types Network.Sendfile.Linux
import-dirs:          /usr/lib/ghc-9.6.6/site-local/simple-sendfile-0.2.32
library-dirs:         /usr/lib/ghc-9.6.6/site-local/simple-sendfile-0.2.32
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/simple-sendfile-0.2.32
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-simple-sendfile
hs-libraries:         HSsimple-sendfile-0.2.32-A2kk7hI8jkyIuonFf6AuD9
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-3.1.4.0-D5In1g0c1o5Lno6WiKQzlZ unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock

haddock-html:         /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

